skillarea

# XMLRésuméLibrary: User Guide

skill | Element Reference | skillareas

## Name

skillarea — A group of broadly related skill sets

## Synopsis

### Content Model

    (title,skillset+)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `skillarea` element contains one or more `skillset`s. Usually the skill sets it contains are related to each other, at least in a general sense.

For example, a “Computer Skills” skill area may contain skillsets titled “Programming”, “Office Programs”, and “Hardware”.

It is quite common for a résumé to contain only one skill area.

### Formatting

The text of skill area's `title` element is displayed as a top-level heading in all output formats. Then all contained skill sets are displayed sequentially. See `skillset` for information about skill set formatting.

### Parents

`skillarea` may be contained in these elements: `resume`, `skillareas`

### Attributes

`id`

  A string used to uniquely identify a skill area. The skill area may then be referred to by this identifier.

## Examples

Example 8. Broad skill area

    <skillarea>
      <title>Skills</title>

      <skillset>
        <title>Computers</title>
        <skill>Typing (<emphasis>150 WPM!!</emphasis>)</skill>
        <skill>Dropping little food crumbs in keyboards</skill>
      </skillset>

      <skillset>
        <title>Writing</title>
        <skill>Editing</skill>
        <skill>Cursive</skill>
      </skillset>
    </skillarea>

Example 9. More focused skill area

    <skillarea>
      <title>Financial Skills</title>

      <skillset>
        <title>Investing</title>
        <skill>Stocks</skill>
        <skill>Bonds</skill>
        <skill>Money market accounts</skill>
        <skill>Retirement accounts</skill>
      </skillset>

      <skillset>
        <title>Bookkeeping</title>
        <skill>Amortization</skill>
        <skill>Loan schedules</skill>
        <skill>Book balancing</skill>
      </skillset>

      <skillset>
        <title>Advising</title>
        <skill>Retirement investment</skill>
        <skill>College investment</skill>
        <skill>Philanthropy</skill>
      </skillset>
    </skillarea>

skill | Element Reference | skillareas